@@ -93,14 +93,18 @@ void json_spy_renderer::set_filter(string filter)
 	if(filter != "")
 	{
 		sinsp_filter_compiler compiler(m_inspector, filter);
-		m_filter = std::move(compiler.compile());
+		m_filter = compiler.compile();
 	}
 }
 
 void json_spy_renderer::process_event_spy(sinsp_evt* evt, int32_t next_res)
 {
 	int64_t len;
-	const char* argstr = m_json_spy_renderer->process_event_spy(evt, &len);
+	const char* argstr = NULL;
+	if(next_res != SCAP_EOF)
+	{
+		argstr = m_json_spy_renderer->process_event_spy(evt, &len);
+	}
 
 	if(argstr != NULL)
 	{
@@ -167,6 +171,11 @@ void json_spy_renderer::process_event_spy(sinsp_evt* evt, int32_t next_res)
 
 void json_spy_renderer::process_event_dig(sinsp_evt* evt, int32_t next_res)
 {
+	if(next_res == SCAP_EOF)
+	{
+		return;
+	}
+
 	if(!m_inspector->is_debug_enabled() && evt->get_category() & EC_INTERNAL)
 	{
 		return;
@@ -184,7 +193,7 @@ void json_spy_renderer::process_event(sinsp_evt* evt, int32_t next_res)
 	//
 	// Filter the event
 	//
-	if(m_filter)
+	if(m_filter && next_res != SCAP_EOF)
 	{
 		if(!m_filter->run(evt))
 		{
@@ -270,6 +279,7 @@ sinsp_cursesui::sinsp_cursesui(sinsp* inspector,
 	m_sorting_col = sorting_col;
 	m_json_spy_renderer = NULL;
 	m_json_spy_text_fmt = json_spy_text_fmt;
+	m_n_progress_reports = 0;
 
 #ifndef NOCURSESUI
 	m_viz = NULL;
@@ -1446,13 +1456,13 @@ Json::Value sinsp_cursesui::generate_json_info_section()
 void sinsp_cursesui::handle_end_of_sample(sinsp_evt* evt, int32_t next_res)
 {
 	vector<chisel_sample_row>* sample;
-	m_datatable->flush(evt);
+	m_datatable->flush(evt, m_last_evt_ts);
 
 	//
 	// It's time to refresh the data for this chart.
 	// First of all, create the data for the chart
 	//
-	if(m_output_type == chisel_table::OT_JSON && (m_inspector->is_live() || (m_eof > 0)))
+	if(m_output_type == chisel_table::OT_JSON && (m_inspector->is_live() || next_res == SCAP_EOF))
 	{
 		printf("{\"progress\": 100, ");
 
@@ -1546,7 +1556,7 @@ void sinsp_cursesui::handle_end_of_sample(sinsp_evt* evt, int32_t next_res)
 				}
 			}
 		}
-*/		
+*/
 #endif
 	}
 }
@@ -2265,7 +2275,7 @@ chisel_table_action sinsp_cursesui::handle_textbox_input(int ch)
 
 					try
 					{
-						f = std::move(compiler.compile());
+						f = compiler.compile();
 					}
 					catch(const sinsp_exception& e)
 					{
