@@ -474,15 +474,19 @@ public:
 	//
 	inline bool process_event(sinsp_evt* evt, int32_t next_res)
 	{
-		uint64_t ts = evt->get_ts();
-		if(!m_inspector->is_live())
+		uint64_t ts = 0;
+		if(next_res != SCAP_EOF)
 		{
-			if(m_1st_evt_ts == 0)
+			ts = evt->get_ts();
+			if(!m_inspector->is_live())
 			{
-				m_1st_evt_ts = ts;	
-			}
+				if(m_1st_evt_ts == 0)
+				{
+					m_1st_evt_ts = ts;
+				}
 
-			m_last_evt_ts = ts;	
+				m_last_evt_ts = ts;
+			}
 		}
 
 		//
@@ -494,17 +498,20 @@ public:
 			if((ts - m_last_input_check_ts > m_input_check_period_ns) || m_eof)
 			{
 				uint32_t ninputs = 0;
-				uint64_t evtnum = evt->get_num();
 
 				//
 				// If this is a file, print the progress once in a while
 				//
 				if(!m_inspector->is_live() && !m_offline_replay)
 				{
-					if(evtnum - m_last_progress_evt > 30000)
+					if(next_res != SCAP_EOF)
 					{
-						print_progress(m_inspector->get_read_progress());
-						m_last_progress_evt = evtnum;
+						uint64_t evtnum = evt->get_num();
+						if(evtnum - m_last_progress_evt > 30000)
+						{
+							print_progress(m_inspector->get_read_progress());
+							m_last_progress_evt = evtnum;
+						}
 					}
 				}
 
@@ -570,12 +577,15 @@ public:
 			//
 			if(!m_inspector->is_live() && !m_offline_replay)
 			{
-				uint64_t evtnum = evt->get_num();
-				if(evtnum - m_last_progress_evt > 300000)
+				if(next_res != SCAP_EOF)
 				{
-				 	printf("{\"progress\": %.2lf},\n", m_inspector->get_read_progress());
-					fflush(stdout);
-					m_last_progress_evt = evtnum;
+					uint64_t evtnum = evt->get_num();
+					if(evtnum - m_last_progress_evt > 300000)
+					{
+						printf("{\"progress\": %.2lf},\n", m_inspector->get_read_progress());
+						fflush(stdout);
+						m_last_progress_evt = evtnum;
+					}
 				}
 			}
 		}
@@ -622,28 +632,30 @@ public:
 		if(m_json_spy_renderer)
 		{
 			m_json_spy_renderer->process_event(evt, next_res);
-			
-			uint64_t evtnum = evt->get_num();
-			if((evtnum - m_last_progress_evt > 2000) || (next_res == SCAP_EOF))
+
+			if(next_res == SCAP_EOF || (evt->get_num() - m_last_progress_evt > 2000))
 			{
 				std::string jdata = m_json_spy_renderer->get_data();
 				double rprogress = m_inspector->get_read_progress();
-				printf("{\"progress\": %.2lf,", rprogress);
-				if(next_res == SCAP_EOF)
-				{
-					printf(" \"count\": %" PRIu64 ", ", m_json_spy_renderer->get_count());
-				}
-				printf("\"data\": %s", jdata.c_str());
-				printf("}");
-
-				if(next_res != SCAP_EOF)
+				if(ts > m_1st_evt_ts || (next_res == SCAP_EOF && m_n_progress_reports > 0))
 				{
+					// We add the comma only after the first progress status update.
 					printf(",");
 				}
+				printf("{\"progress\": %.2lf, \"count\": %" PRIu64 ", \"data\": %s}",
+					   rprogress,
+					   m_json_spy_renderer->get_count(),
+					   jdata.c_str());
+				m_n_progress_reports++;
 
 				fflush(stdout);
+			}
 
-				m_last_progress_evt = evtnum;
+			if(next_res != SCAP_EOF)
+			{
+				// We update the value only if we have
+				// an event.
+				m_last_progress_evt = evt->get_num();
 			}
 
 			//
@@ -679,18 +691,15 @@ public:
 				//
 				// For files, we flush only once, at the end of the capture.
 				//
-				if(next_res == SCAP_EOF)
-				{
-					end_of_sample = true;
-				}
-				else
-				{
-					end_of_sample = false;
-				}
+				end_of_sample = (!m_eof && next_res == SCAP_EOF);
 			}
 
 			if(end_of_sample)
 			{
+				if(next_res == SCAP_EOF && !m_inspector->is_live())
+				{
+					evt = nullptr;
+				}
 				handle_end_of_sample(evt, next_res);
 
 				//
@@ -700,7 +709,14 @@ public:
 				{
 					ASSERT(!m_inspector->is_live());
 					m_eof++;
-					return false;
+					if(m_output_type == chisel_table::OT_CURSES)
+					{
+						return false;
+					}
+					else
+					{
+						return true;
+					}
 				}
 			}
 
@@ -811,5 +827,6 @@ private:
 	int32_t m_sorting_col;
 	json_spy_renderer* m_json_spy_renderer;
 	sinsp_evt::param_fmt m_json_spy_text_fmt;
+	uint64_t m_n_progress_reports;
 };
 
