@@ -72,6 +72,12 @@ static std::atomic<bool> g_plugin_input = false;
 std::vector<sinsp_chisel*> g_chisels;
 #endif
 
+enum color_term_out {
+  COLOR = 0,
+  NO_COLOR,
+  FORCE_COLOR
+};
+
 static void usage();
 
 //
@@ -290,6 +296,8 @@ static void usage()
 " -M <num_seconds>   Stop collecting after <num_seconds> reached.\n"
 " -n <num>, --numevents=<num>\n"
 "                    Stop capturing after <num> events\n"
+" --color <true|force|false> \n"
+"                    Set colors settings on terminal output.\n"
 " --page-faults      Capture user/kernel major/minor page faults\n"
 " --plugin-config-file\n"
 "                    Load the plugin configuration from a Falco-compatible yaml file.\n"
@@ -658,14 +666,6 @@ void handle_end_of_file(sinsp* inspector, bool print_progress, bool reset_colors
 {
 	std::string line;
 
-	// Notify the formatter that we are at the
-	// end of the capture in case it needs to
-	// write any terminating characters
-	if(formatter != NULL && formatter->on_capture_end(&line))
-	{
-		std::cout << line << std::endl;
-	}
-
 	if(reset_colors) {
 		std::cout << "\e[00m";
 	}
@@ -790,7 +790,21 @@ captureinfo do_inspect(sinsp* inspector,
 		{
 			dumper->dump(ev);
 		}
-
+		else if(res == SCAP_FAILURE && !inspector->is_live())
+		{
+			//
+			// scap file truncated.
+			//
+			// We fail gracefully:
+			// - all the expected output (except truncated
+			//   events) will be on stdout
+			// - the return code will be set as success
+			// - the inspector error will be on stderr
+			//
+			handle_end_of_file(inspector, print_progress, reset_colors, formatter);
+			std::cerr << inspector->getlasterr() << std::endl;
+			break;
+		}
 		if(res == SCAP_TIMEOUT || res == SCAP_FILTERED_EVENT)
 		{
 			if(res == SCAP_FILTERED_EVENT && ev != NULL && ev->is_filtered_out())
@@ -955,6 +969,15 @@ void disable_tty_echo() {
 }
 #endif
 
+static inline bool stdout_supports_color()
+{
+#ifdef _WIN32
+    return false;
+#else
+    return isatty(fileno(stdout));
+#endif
+}
+
 std::string escape_output_format(const std::string& s)
 {
     std::stringstream  ss{""};
@@ -1031,6 +1054,8 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	sinsp_opener opener;
 	std::unique_ptr<filter_check_list> filter_list;
 	std::shared_ptr<sinsp_filter_factory> filter_factory;
+	color_term_out color_flag = COLOR;
+	bool user_defined_format = false;
 
 	// These variables are for the cycle_writer engine
 	int duration_seconds = 0;
@@ -1104,22 +1129,10 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{"print-hex", no_argument, 0, 'x'},
 		{"print-hex-ascii", no_argument, 0, 'X'},
 		{"compress", no_argument, 0, 'z' },
+		{"color", required_argument, 0, 0 },
 		{0, 0, 0, 0}
 	};
 
-#ifndef _WIN32
-	if (isatty(fileno(stdout)))
-	{
-		output_format = R"(*%evt.num %evt.outputtime %evt.cpu \e[01;32m%proc.name\e[00m (\e[01;36m%proc.pid\e[00m.%thread.tid) %evt.dir \e[01;34m%evt.type\e[00m %evt.info)";
-		output_format_plugin = R"(*%evt.num %evt.datetime.s [\e[01;32m%evt.pluginname\e[00m] %evt.plugininfo)";
-	}
-	else
-#endif
-	{
-		output_format = "*%evt.num %evt.outputtime %evt.cpu %proc.name (%thread.tid) %evt.dir %evt.type %evt.info";
-		output_format_plugin = "*%evt.num %evt.datetime.s [%evt.pluginname] %evt.plugininfo";
-	}
-
 	try
 	{
 		inspector.reset(new sinsp());
@@ -1415,6 +1428,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 					output_format = optarg;
 					output_format_plugin = optarg;
 				}
+				user_defined_format = true;
 
 				break;
 			case 'q':
@@ -1634,6 +1648,28 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 						plugins.print_plugin_info(inspector.get(), filter_list.get(), name);
 						return sysdig_init_res(EXIT_SUCCESS);
 					}
+
+					else if (optname == "color")
+					{
+						auto color_state = std::string(optarg);
+						if (color_state == "true")
+						{
+							color_flag = COLOR;
+						}
+						else if (color_state == "force")
+						{
+							color_flag = FORCE_COLOR;
+						}
+						else if (color_state == "false")
+						{
+							color_flag = NO_COLOR;
+						}
+						else
+						{
+							fprintf(stderr, "invalid color mode for flag --color\n");
+							return sysdig_init_res(EXIT_FAILURE);
+						}
+					}
 				}
 				break;
 			// getopt_long : '?' for an ambiguous match or an extraneous parameter
@@ -1645,6 +1681,22 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			}
 		}
 
+		if(!user_defined_format)
+		{
+			char* no_color_env = getenv("NO_COLOR");
+			if ((color_flag == FORCE_COLOR) ||
+				(stdout_supports_color() && no_color_env == nullptr && color_flag == COLOR))
+			{
+				output_format = R"(*%evt.num %evt.outputtime %evt.cpu \e[01;32m%proc.name\e[00m (\e[01;36m%proc.pid\e[00m.%thread.tid) %evt.dir \e[01;34m%evt.type\e[00m %evt.info)";
+				output_format_plugin = R"(*%evt.num %evt.datetime.s [\e[01;32m%evt.pluginname\e[00m] %evt.plugininfo)";
+			}
+			else
+			{
+				output_format = "*%evt.num %evt.outputtime %evt.cpu %proc.name (%thread.tid) %evt.dir %evt.type %evt.info";
+				output_format_plugin = "*%evt.num %evt.datetime.s [%evt.pluginname] %evt.plugininfo";
+			}
+		}
+
 		// given the CLI options, we finish loading and initializing plugins.
 		// if no plugin has been specified as input with -I, we try to
 		// reload the config file (if present), and set the input plugin 
@@ -1861,8 +1913,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			{
 				try
 				{
-					sinsp_filter_compiler compiler(filter_factory, filter);
-					inspector->set_filter(compiler.compile());
+					inspector->set_filter(filter);
 				}
 				catch (sinsp_exception& e)
 				{
